..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


.. rubric:: Bibliography

.. bibliography:: references.bib
   :all:
   :style: plain
